#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-FipbHiFLYXZ7eeGWINhIBL
key:                  ptr-0.16.8.7-FipbHiFLYXZ7eeGWINhIBL
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  892ada7bcbf6b0e0a24153cafcdcdcf9
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-FipbHiFLYXZ7eeGWINhIBL
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    profunctors-5.6.3-BXRHkLDrrb9JFsAZO6kADg
    strict-list-0.1.7.6-17RmqCpRV9wAgZuXR3bVq5 text-2.0.2 time-1.12.2
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

